FlashXTest
==========

Installation
------------

-  Use ``./setup develop`` for development mode

-  Or use ``./setup install`` to install package
   on your system

-  You are good to go. Now you can simply type ``flashxtest`` on your
   command line and it will be availabe, or you can import the Python API using
   ``import FlashXTest.api as flashxtest``

Tests
-----

A copy of tests currently run on nightly test suite are located in ``Tests/``

Examples
--------

Examples for using FlashXTest are locate in ``Examples/``
